@@ -75,7 +75,7 @@ Plugin.create(:activity) do
       else
         storage << id
         result << false end }
-    not result.all?(&ret_nth) end
+    not result.all? end
 
   # アクティビティの古い通知を一定時間後に消す
   def reset_activity(model)
@@ -90,6 +90,26 @@ Plugin.create(:activity) do
           reset_activity(model) end } }
   end
 
+  def gen_listener_for_visible_check(uc, kind)
+    UserConfig[uc] ||= []
+    Plugin::Settings::Listener.new \
+      get: ->(){ UserConfig[uc].include?(kind) rescue false },
+      set: ->(value) do
+        if value
+          UserConfig[uc] += [kind]
+        else
+          UserConfig[uc] -= [kind] end end end
+
+  def gen_listener_for_invisible_check(uc, kind)
+    UserConfig[uc] ||= []
+    Plugin::Settings::Listener.new \
+      get: ->(){ (not UserConfig[uc].include?(kind)) rescue true },
+      set: ->(value) do
+        unless value
+          UserConfig[uc] += [kind]
+        else
+          UserConfig[uc] -= [kind] end end end
+
   # アクティビティを更新する。
   # ==== Args
   # [kind] Symbol イベントの種類
@@ -188,7 +208,7 @@ Plugin.create(:activity) do
                           "@#{message.user[:idname]}: #{message.to_s}\n"+
                           message.parma_link),
              icon: user[:profile_image_url],
-             related: message.user.is_me? || user.is_me?,
+             related: message.user.me? || user.me?,
              service: service)
   end
 
@@ -198,7 +218,7 @@ Plugin.create(:activity) do
                           "@#{message.user[:idname]}: #{message.to_s}\n"+
                           message.parma_link),
              icon: user[:profile_image_url],
-             related: message.user.is_me? || user.is_me?,
+             related: message.user.me? || user.me?,
              service: service)
   end
 
@@ -211,7 +231,7 @@ Plugin.create(:activity) do
                               source.parma_link),
                  icon: retweet.user[:profile_image_url],
                  date: retweet[:created],
-                 related: (retweet.user.is_me? || source && source.user.is_me?),
+                 related: (retweet.user.me? || source && source.user.me?),
                  service: Service.primary) }.terminate(_ 'リツイートソースが取得できませんでした') }
   end
 
@@ -228,7 +248,7 @@ Plugin.create(:activity) do
                             _("%{description} (by @%{user})") % desc_by_user + "\n" +
                             "https://twitter.com/#{list.user[:idname]}/#{list[:slug]}"),
                icon: user[:profile_image_url],
-               related: user.is_me? || source_user.is_me?,
+               related: user.me? || source_user.me?,
                service: service) end
   end
 
@@ -245,7 +265,7 @@ Plugin.create(:activity) do
                             _("%{description} (by @%{user})") % desc_by_user + "\n" +
                             "https://twitter.com/#{list.user[:idname]}/#{list[:slug]}"),
                icon: user[:profile_image_url],
-               related: user.is_me? || source_user.is_me?,
+               related: user.me? || source_user.me?,
                service: service) end
   end
 
@@ -255,15 +275,15 @@ Plugin.create(:activity) do
         followee: by[:idname],
         follower: to[:idname] }
       activity(:follow, _("@%{followee} が @%{follower} をﾌｮﾛｰしました") % by_user_to_user,
-               related: by.is_me? || to.is_me?,
-               icon: (to.is_me? ? by : to)[:profile_image_url]) end
+               related: by.me? || to.me?,
+               icon: (to.me? ? by : to)[:profile_image_url]) end
   end
 
   on_direct_messages do |service, dms|
     dms.each{ |dm|
       date = Time.parse(dm[:created_at])
       if date > BOOT_TIME
-        first_line = dm[:sender].is_me? ? _("ダイレクトメッセージを送信しました") : _("ダイレクトメッセージを受信しました")
+        first_line = dm[:sender].me? ? _("ダイレクトメッセージを送信しました") : _("ダイレクトメッセージを受信しました")
         title = _("D %{recipient} %{text}") % {
           recipient: dm[:recipient][:idname],
           text: dm[:text] }
@@ -292,22 +312,17 @@ Plugin.create(:activity) do
       activity_kind_order = []
       activity_kind = {} end
 
-    settings _("表示しないイベント") do
-      multiselect(_("以下の自分に関係ないイベント"), :activity_mute_kind_related) do
-        activity_kind_order.each{ |kind|
-          option kind, activity_kind[kind] } end
-
-      multiselect(_("以下の全てのイベント"), :activity_mute_kind) do
-        activity_kind_order.each{ |kind|
-          option kind, activity_kind[kind] } end end
-
-    multiselect(_("タイムラインに表示"), :activity_show_timeline) do
-      activity_kind_order.each{ |kind|
-        option kind, activity_kind[kind] } end
-
-    multiselect(_("ステータスバーに表示"), :activity_show_statusbar) do
-      activity_kind_order.each{ |kind|
-        option kind, activity_kind[kind] } end end
+    activity_kind_order.each do |kind|
+      name = activity_kind[kind]
+      ml_param = {name: name}
+      settings name do
+        boolean(_('%{name}を表示する') % ml_param, gen_listener_for_invisible_check(:activity_mute_kind, kind)).tooltip(_('%{name}を、アクティビティタイムラインに表示します。チェックを外すと、%{name}の他の設定は無効になります。') % ml_param)
+        boolean(_('自分に関係ない%{name}も表示する') % ml_param, gen_listener_for_invisible_check(:activity_mute_kind_related, kind)).tooltip(_('自分に関係ない%{name}もアクティビティタイムラインに表示されるようになります。チェックを外すと、自分に関係ない%{name}は表示されません。') % ml_param)
+        boolean(_('タイムラインに表示'), gen_listener_for_visible_check(:activity_show_timeline, kind)).tooltip(_('%{name}が通知された時に、システムメッセージで%{name}を通知します') % ml_param)
+        boolean(_('ステータスバーに表示'), gen_listener_for_visible_check(:activity_show_statusbar, kind)).tooltip(_('%{name}が通知された時に、ステータスバーにしばらく表示します') % ml_param)
+      end
+    end
+  end
 
   defactivity "retweet", _("リツイート")
   defactivity "favorite", _("ふぁぼ")
