@@ -3,6 +3,57 @@
 require File.expand_path File.join(File.dirname(__FILE__), 'edit_window')
 require File.expand_path File.join(File.dirname(__FILE__), 'extract_tab_list')
 
+module Plugin::Extract
+  class ConditionNotFoundError < RuntimeError; end
+
+  ExtensibleCondition = Struct.new(:slug, :name, :operator, :args) do
+    def initialize(*_args, &block)
+      super
+      @block = block end
+
+    def to_proc
+      @block end
+
+    def call(*_args, **_named, &block)
+      @block.(*_args, **_named, &block) end end
+
+  class ExtensibleSexpCondition < ExtensibleCondition
+    attr_reader :sexp
+
+    def initialize(*args)
+      @sexp = args.pop
+      super(*args) end
+  end
+
+  ExtensibleOperator = Struct.new(:slug, :name, :args) do
+    def initialize(*_args, &block)
+      super
+      @block = block end
+
+    def to_proc
+      @block end
+
+    def call(*_args, **_named, &block)
+      @block.(*_args, **_named, &block) end end
+
+  class Calc
+    def initialize(message, condition, operators = Plugin.filtering(:extract_operator, Set.new).first)
+      type_strict message => Message, condition => Plugin::Extract::ExtensibleCondition, operators => Enumerable
+      @message, @condition, @operators = message, condition, operators
+    end
+
+    def method_missing(method_name, *args)
+      operator = @operators.find{ |_| _.slug == method_name }
+      if operator
+        @condition.(*args, message: @message, operator: operator.slug, &operator)
+      else
+        super end end
+
+    def call(*args)
+      @condition.(*args, message: @message) end
+  end
+end
+
 Plugin.create :extract do
 
   # 抽出タブオブジェクト。各キーは抽出タブIDで、値は以下のようなオブジェクト
@@ -54,6 +105,32 @@ Plugin.create :extract do
     Plugin.call(:extract_open_edit_dialog, extract_id) if extract_tabs[extract_id]
   end
 
+  defdsl :defextractcondition do |slug, name: raise, operator: true, args: 0, sexp: nil, &block|
+    if sexp
+      filter_extract_condition do |conditions|
+        conditions << Plugin::Extract::ExtensibleSexpCondition.new(slug, name, operator, args, sexp).freeze
+        [conditions] end
+    else
+      filter_extract_condition do |conditions|
+        conditions << Plugin::Extract::ExtensibleCondition.new(slug, name, operator, args, &block).freeze
+        [conditions] end end end
+
+  defdsl :defextractoperator do |slug, name: raise, args: 1, &block|
+    filter_extract_operator do |operators|
+      operators << Plugin::Extract::ExtensibleOperator.new(slug, name, args, &block).freeze
+      [operators] end end
+
+  defextractoperator(:==, name: '＝', args: 1, &:==)
+  defextractoperator(:!=, name: '≠', args: 1, &:!=)
+  defextractoperator(:match_regexp, name: '正規表現', args: 1, &:match_regexp)
+  defextractoperator(:include?, name: '含む', args: 1, &:include?)
+
+  defextractcondition(:user, name: 'ユーザ名', operator: true, args: 1, sexp: MIKU.parse("`(,compare (idname (user message)) ,(car args))"))
+
+  defextractcondition(:body, name: '本文', operator: true, args: 1, sexp: MIKU.parse("`(,compare (to_s message) ,(car args))"))
+
+  defextractcondition(:source, name: 'Twitterクライアント', operator: true, args: 1, sexp: MIKU.parse("`(,compare (fetch message 'source) ,(car args))"))
+
   on_extract_tab_create do |record|
     record[:id] = Time.now.to_i unless record[:id]
     slug = "extract_#{record[:id]}".to_sym
@@ -155,21 +232,76 @@ Plugin.create :extract do
 
   # 使用されているデータソースのSetを返す
   def active_datasources
-    @active_datasources ||= extract_tabs.values.inject(Set.new){|set,tab| set.merge(tab[:sources]) }.freeze end
+    @active_datasources ||=
+      extract_tabs.values.map{|tab|
+        tab[:sources]
+      }.select{|sources|
+        sources.is_a? Enumerable
+      }.inject(Set.new, &:merge).freeze end
 
   def compile(tab_id, code)
     atomic do
       @compiled ||= {}
-      if code.empty?
-        @compiled[tab_id] ||= ret_nth
+      @compiled[tab_id] ||=
+        if code.empty?
+          ret_nth
+        else
+          begin
+            before = Set.new
+            extract_condition ||= Hash[Plugin.filtering(:extract_condition, []).first.map{ |condition| [condition.slug, condition] }]
+            evaluated = MIKU::Primitive.new(:to_ruby_ne).call(MIKU::SymbolTable.new, metamorphose(code: code, assign: before, extract_condition: extract_condition))
+            code_string = "lambda{ |message|\n" + before.to_a.join("\n") + "\n  " + evaluated + "\n}"
+            notice code_string
+            instance_eval(code_string)
+          rescue Plugin::Extract::ConditionNotFoundError => exception
+            Plugin.call(:modify_activity,
+                        plugin: self,
+                        kind: 'error'.freeze,
+                        title: "抽出タブ条件エラー",
+                        date: Time.new,
+                        description: _("抽出タブ「%{tab_name}」で使われている条件が見つかりませんでした:\n%{error_string}") % {tab_name: extract_tabs[tab_id][:name], error_string: exception.to_s})
+            warn exception
+            ret_nth end end end end
+
+  # 条件をこう、くいっと変形させてな
+  def metamorphose(code: raise, assign: Set.new, extract_condition: nil)
+    extract_condition ||= Hash[Plugin.filtering(:extract_condition, []).first.map{ |condition| [condition.slug, condition] }]
+    case code
+    when MIKU::Atom
+      return code
+    when MIKU::List
+      condition = if code.size <= 2
+                    extract_condition[code.car]
+                  else
+                    extract_condition[code.cdr.car] end
+      case condition
+      when Plugin::Extract::ExtensibleSexpCondition
+        metamorphose_sexp(code: code, condition: condition)
+      when Plugin::Extract::ExtensibleCondition
+        assign << "#{condition.slug} = Plugin::Extract::Calc.new(message, extract_condition[:#{condition.slug}])"
+        if condition.operator
+          code
+        else
+          # MIKU::Cons.new(:call, MIKU::Cons.new(condition.slug, nil))
+          [:call, condition.slug]
+        end
       else
-        @compiled[tab_id] ||= ->(assign,evaluated){
-          assign += "  user = message.idname\n"     if evaluated.include? "user"
-          assign += "  body = message.to_s\n"       if evaluated.include? "body"
-          assign += "  source = message[:source]\n" if evaluated.include? "source"
-          notice "tab code: lambda{ |message|\n" + assign + "  " + evaluated + "\n}"
-          eval("lambda{ |message|\n" + assign + "  " + evaluated + "\n}")
-        }.("",MIKU::Primitive.new(:to_ruby_ne).call(MIKU::SymbolTable.new, code)) end end end
+        if code.cdr.car.is_a? Symbol and not %i[and or not].include?(code.car)
+          raise Plugin::Extract::ConditionNotFoundError, _('抽出条件 `%{condition}\' が見つかりませんでした') % {condition: code.cdr.car} end
+        code.map{|node| metamorphose(code: node,
+                                     assign: assign,
+                                     extract_condition: extract_condition) } end end end
+
+  def metamorphose_sexp(code: raise, condition: raise)
+    miku_context = MIKU::SymbolTable.new
+    miku_context[:compare] = MIKU::Cons.new(code.car, nil)
+    miku_context[:args] = MIKU::Cons.new(code.cdr.cdr, nil)
+    begin
+      miku(condition.sexp, miku_context)
+    rescue => exception
+      error "error occured in code #{MIKU.unparse(condition.sexp)}"
+      notice miku_context
+      raise exception end end
 
   def destroy_compile_cache
     atomic do
